@@ -4,26 +4,23 @@
 Unittests for jamf.package
 """
 
-__author__ = 'Sam Forester'
-__email__ = 'sam.forester@utah.edu'
-__copyright__ = 'Copyright (c) 2020 University of Utah, Marriott Library'
-__license__ = 'MIT'
+__author__ = "Sam Forester"
+__email__ = "sam.forester@utah.edu"
+__copyright__ = "Copyright (c) 2020 University of Utah, Marriott Library"
+__license__ = "MIT"
 __version__ = "1.0.1"
 
-# import os
-import pprint
-import shutil
 import pathlib
+import shutil
 import unittest
 
 from jamf import package
-from jamf import api
-from jamf import category
 
 # location for temporary files created with tests
 LOCATION = pathlib.Path(__file__).parent
-TMPDIR = LOCATION / 'tmp' / 'package'
-DATA = LOCATION / 'data' / 'package'
+TMPDIR = LOCATION / "tmp" / "package"
+DATA = LOCATION / "data" / "package"
+
 
 def setUpModule():
     """
@@ -32,7 +29,7 @@ def setUpModule():
     """
     # OPTIONAL
     TMPDIR.mkdir(mode=0o755, parents=True, exist_ok=True)
-    package.TMPDIR = TMPDIR / 'edu.utah.mlib.package.tests'
+    package.TMPDIR = TMPDIR / "edu.utah.mlib.package.tests"
 
 
 def tearDownModule():
@@ -44,7 +41,6 @@ def tearDownModule():
 
 
 class BaseTestCase(unittest.TestCase):
-
     @classmethod
     def setUpClass(cls):
         pass
@@ -70,7 +66,7 @@ class TestPackageInit(BaseTestCase):
         """
         test FileNotFoundError is raised when given a bad path
         """
-        path = pathlib.Path('/does/not/exist')
+        path = pathlib.Path("/does/not/exist")
         if not path.exists():
             with self.assertRaises(FileNotFoundError):
                 package.Package(path)
@@ -79,16 +75,15 @@ class TestPackageInit(BaseTestCase):
         """
         test initialization succeeds
         """
-        path = DATA / 'pkgs' / 'edu.utah.mlib.package.test.pkg'
+        path = DATA / "pkgs" / "edu.utah.mlib.package.test.pkg"
         if path.exists():
-            pkg = package.Package(path)
+            _ = package.Package(path)
 
 
 class PackageTests(BaseTestCase):
-
     def setUp(self):
         super().setUp()
-        self.path = DATA / 'pkgs' / 'edu.utah.mlib.package.test.pkg'
+        self.path = DATA / "pkgs" / "edu.utah.mlib.package.test.pkg"
         self.pkg = package.Package(self.path)
 
     def test_sha512_checksum(self):
@@ -96,9 +91,11 @@ class PackageTests(BaseTestCase):
         test package sha512 checksum hexdigest
         """
         # `openssl sha512 /path/to/edu.utah.mlib.package.test.pkg`
-        expected = ('137aa99516b7c9e4d9e8e11e7fffbeb706f380886ff'
-                    '390da0b786053993903acc1190e3c27c1cde054f351'
-                    '5369e449f33be15c287aeba116d2e9f1a8dc2f5ff9')
+        expected = (
+            "137aa99516b7c9e4d9e8e11e7fffbeb706f380886ff"
+            "390da0b786053993903acc1190e3c27c1cde054f351"
+            "5369e449f33be15c287aeba116d2e9f1a8dc2f5ff9"
+        )
         result = self.pkg.sha512
         self.assertEqual(expected, result)
 
@@ -107,7 +104,7 @@ class PackageTests(BaseTestCase):
         test package md5 checksum hexdigest
         """
         # `openssl md5 /path/to/edu.utah.mlib.package.test.pkg`
-        expected = 'a37ae984343b3bbcedb7316e0f3cb349'
+        expected = "a37ae984343b3bbcedb7316e0f3cb349"
         result = self.pkg.md5
         self.assertEqual(expected, result)
 
@@ -131,7 +128,7 @@ class PackageTests(BaseTestCase):
         """
         test all package info keys are accounted for
         """
-        expected = ['contents', 'name', 'path', 'pkginfo']
+        expected = ["contents", "name", "path", "pkginfo"]
         result = sorted([str(x) for x in self.pkg.info.keys()])
         self.assertEqual(expected, result)
 
@@ -139,7 +136,7 @@ class PackageTests(BaseTestCase):
         """
         test package identifier
         """
-        expected = 'test.package'
+        expected = "test.package"
         result = self.pkg.identifier
         self.assertEqual(expected, result)
 
@@ -147,7 +144,7 @@ class PackageTests(BaseTestCase):
         """
         test package version
         """
-        expected = '1.0.1'
+        expected = "1.0.1"
         result = self.pkg.version
         self.assertEqual(expected, result)
 
@@ -155,7 +152,7 @@ class PackageTests(BaseTestCase):
         """
         test package install-location
         """
-        expected = '/Applications/Test Package'
+        expected = "/Applications/Test Package"
         result = self.pkg.location
         self.assertEqual(expected, result)
 
@@ -163,12 +160,16 @@ class PackageTests(BaseTestCase):
         """
         test package app
         """
-        expected = [{'CFBundleIdentifier': 'edu.utah.mlib.package.test',
-                     'CFBundleShortVersionString': '1.0.0',
-                     'CFBundleVersion': '100',
-                     'LSMinimumSystemVersion': '10.7.5',
-                     'name': 'package.app',
-                     'path': '/Applications/Test Package/package.app'}]
+        expected = [
+            {
+                "CFBundleIdentifier": "edu.utah.mlib.package.test",
+                "CFBundleShortVersionString": "1.0.0",
+                "CFBundleVersion": "100",
+                "LSMinimumSystemVersion": "10.7.5",
+                "name": "package.app",
+                "path": "/Applications/Test Package/package.app",
+            }
+        ]
         result = self.pkg.apps
         self.assertEqual(expected, result)
 
@@ -176,16 +177,18 @@ class PackageTests(BaseTestCase):
         """
         test package information
         """
-        expected = {'auth': 'root',
-                    'format-version': '2',
-                    'generator-version': 'InstallCmds-681 (18G2022)',
-                    'identifier': 'test.package',
-                    'install-location': '/Applications/Test Package',
-                    'overwrite-permissions': 'true',
-                    'postinstall-action': 'none',
-                    'relocatable': 'false',
-                    'version': '1.0.1'}
-        result = self.pkg.info['pkginfo']
+        expected = {
+            "auth": "root",
+            "format-version": "2",
+            "generator-version": "InstallCmds-681 (18G2022)",
+            "identifier": "test.package",
+            "install-location": "/Applications/Test Package",
+            "overwrite-permissions": "true",
+            "postinstall-action": "none",
+            "relocatable": "false",
+            "version": "1.0.1",
+        }
+        result = self.pkg.info["pkginfo"]
         self.assertEqual(expected, result)
 
     def test_size(self):
@@ -208,7 +211,7 @@ class PackageTests(BaseTestCase):
         test package expansion cleanup
         """
         path = self.pkg.expand()
-        del(self.pkg)
+        del self.pkg
         self.assertFalse(path.exists())
 
     def test_pkg_as_str(self):
@@ -219,6 +222,5 @@ class PackageTests(BaseTestCase):
         self.assertTrue(str(self.pkg) == expected)
 
 
-
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main(verbosity=1)
